@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 
-package Perl::PrereqScanner::Scanner::Moose 1.025;
+package Perl::PrereqScanner::Scanner::Moose 1.100;
 # ABSTRACT: scan for Moose sugar indicators of required modules
 
-use Moose;
+use Moo;
 with 'Perl::PrereqScanner::Scanner';
 
 #pod =head1 DESCRIPTION
@@ -138,7 +138,7 @@ Perl::PrereqScanner::Scanner::Moose - scan for Moose sugar indicators of require
 
 =head1 VERSION
 
-version 1.025
+version 1.100
 
 =head1 DESCRIPTION
 
